@@ -1,7 +1,6 @@
 use anyhow::{format_err, Error};
 use futures::future::join;
 use serde::{Deserialize, Serialize};
-use stack_string::{SmallString, StackString};
 use structopt::StructOpt;
 
 #[cfg(feature = "cli")]
@@ -9,6 +8,7 @@ use tokio::io::{stdout, AsyncWriteExt};
 
 use crate::{
     config::Config, latitude::Latitude, longitude::Longitude, weather_api::WeatherLocation,
+    StringType, ApiStringType,
 };
 
 #[cfg(feature = "cli")]
@@ -26,10 +26,10 @@ pub struct WeatherOpts {
     zipcode: Option<u64>,
     /// Country Code (optional), if not specified `us` will be assumed
     #[structopt(short, long)]
-    country_code: Option<StackString>,
+    country_code: Option<StringType>,
     /// City Name (optional)
     #[structopt(long)]
-    city_name: Option<StackString>,
+    city_name: Option<StringType>,
     /// Latitude (must also specify Longitude)
     #[structopt(long)]
     lat: Option<Latitude>,
@@ -39,7 +39,7 @@ pub struct WeatherOpts {
     /// Api key (optional but either this or API_KEY environment variable must
     /// exist)
     #[structopt(short = "k", long)]
-    api_key: Option<SmallString<32>>,
+    api_key: Option<ApiStringType>,
     /// Print forecast
     #[serde(default)]
     #[structopt(short, long)]
@@ -114,7 +114,7 @@ impl WeatherOpts {
     /// # Errors
     ///
     /// Returns error if call to retreive weather data fails
-    async fn run_opts(&self, config: &Config) -> Result<Vec<StackString>, Error> {
+    async fn run_opts(&self, config: &Config) -> Result<Vec<StringType>, Error> {
         let api = self.get_api(config)?;
         let loc = self.get_location()?;
 
